@@ -37,7 +37,12 @@ type CommitListBuilder struct {
 }
 
 // NewCommitListBuilder builds a new commit list builder
-func NewCommitListBuilder(log *logrus.Entry, gitCommand *GitCommand, osCommand *oscommands.OSCommand, tr *i18n.TranslationSet) *CommitListBuilder {
+func NewCommitListBuilder(
+	log *logrus.Entry,
+	gitCommand *GitCommand,
+	osCommand *oscommands.OSCommand,
+	tr *i18n.TranslationSet,
+) *CommitListBuilder {
 	return &CommitListBuilder{
 		Log:        log,
 		GitCommand: gitCommand,
@@ -88,6 +93,8 @@ type GetCommitsOptions struct {
 	FilterPath           string
 	IncludeRebaseCommits bool
 	RefName              string // e.g. "HEAD" or "my_branch"
+	// determines if we show the whole git graph i.e. pass the '--all' flag
+	All bool
 }
 
 func (c *CommitListBuilder) MergeRebasingCommits(commits []*models.Commit) ([]*models.Commit, error) {
@@ -110,7 +117,7 @@ func (c *CommitListBuilder) MergeRebasingCommits(commits []*models.Commit) ([]*m
 		return result, nil
 	}
 
-	rebasingCommits, err := c.getRebasingCommits(rebaseMode)
+	rebasingCommits, err := c.getHydratedRebasingCommits(rebaseMode)
 	if err != nil {
 		return nil, err
 	}
@@ -149,7 +156,7 @@ func (c *CommitListBuilder) GetCommits(opts GetCommitsOptions) ([]*models.Commit
 	cmd := c.getLogCmd(opts)
 
 	err = oscommands.RunLineOutputCmd(cmd, func(line string) (bool, error) {
-		if strings.Split(line, " ")[0] != "gpg:" {
+		if canExtractCommit(line) {
 			commit := c.extractCommitFromLine(line)
 			if commit.Sha == firstPushedCommit {
 				passedFirstPushedCommit = true
@@ -177,6 +184,51 @@ func (c *CommitListBuilder) GetCommits(opts GetCommitsOptions) ([]*models.Commit
 	return commits, nil
 }
 
+func (c *CommitListBuilder) getHydratedRebasingCommits(rebaseMode string) ([]*models.Commit, error) {
+	commits, err := c.getRebasingCommits(rebaseMode)
+	if err != nil {
+		return nil, err
+	}
+
+	if len(commits) == 0 {
+		return nil, nil
+	}
+
+	commitShas := make([]string, len(commits))
+	for i, commit := range commits {
+		commitShas[i] = commit.Sha
+	}
+
+	// note that we're not filtering these as we do non-rebasing commits just because
+	// I suspect that will cause some damage
+	cmd := c.OSCommand.ExecutableFromString(
+		fmt.Sprintf(
+			"git show %s --no-patch --oneline %s --abbrev=%d",
+			strings.Join(commitShas, " "),
+			prettyFormat,
+			20,
+		),
+	)
+
+	hydratedCommits := make([]*models.Commit, 0, len(commits))
+	i := 0
+	err = oscommands.RunLineOutputCmd(cmd, func(line string) (bool, error) {
+		if canExtractCommit(line) {
+			commit := c.extractCommitFromLine(line)
+			matchingCommit := commits[i]
+			commit.Action = matchingCommit.Action
+			commit.Status = matchingCommit.Status
+			hydratedCommits = append(hydratedCommits, commit)
+			i++
+		}
+		return false, nil
+	})
+	if err != nil {
+		return nil, err
+	}
+	return hydratedCommits, nil
+}
+
 // getRebasingCommits obtains the commits that we're in the process of rebasing
 func (c *CommitListBuilder) getRebasingCommits(rebaseMode string) ([]*models.Commit, error) {
 	switch rebaseMode {
@@ -359,18 +411,37 @@ func (c *CommitListBuilder) getLogCmd(opts GetCommitsOptions) *exec.Cmd {
 		filterFlag = fmt.Sprintf(" --follow -- %s", c.OSCommand.Quote(opts.FilterPath))
 	}
 
+	config := c.GitCommand.Config.GetUserConfig().Git.Log
+
+	orderFlag := "--" + config.Order
+	allFlag := ""
+	if opts.All {
+		allFlag = " --all"
+	}
+
 	return c.OSCommand.ExecutableFromString(
 		fmt.Sprintf(
-			"git log %s --oneline --pretty=format:\"%%H%s%%at%s%%aN%s%%d%s%%p%s%%s\" %s --abbrev=%d %s",
+			"git log %s %s %s --oneline %s %s --abbrev=%d %s",
 			c.OSCommand.Quote(opts.RefName),
-			SEPARATION_CHAR,
-			SEPARATION_CHAR,
-			SEPARATION_CHAR,
-			SEPARATION_CHAR,
-			SEPARATION_CHAR,
+			orderFlag,
+			allFlag,
+			prettyFormat,
 			limitFlag,
 			20,
 			filterFlag,
 		),
 	)
 }
+
+var prettyFormat = fmt.Sprintf(
+	"--pretty=format:\"%%H%s%%at%s%%aN%s%%d%s%%p%s%%s\"",
+	SEPARATION_CHAR,
+	SEPARATION_CHAR,
+	SEPARATION_CHAR,
+	SEPARATION_CHAR,
+	SEPARATION_CHAR,
+)
+
+func canExtractCommit(line string) bool {
+	return strings.Split(line, " ")[0] != "gpg:"
+}
