@@ -285,9 +285,9 @@ func (gui *Gui) currentContextWithoutLock() Context {
 
 // the status panel is not yet a list context (and may never be), so this method is not
 // quite the same as currentSideContext()
-func (gui *Gui) currentSideListContext() *ListContext {
+func (gui *Gui) currentSideListContext() IListContext {
 	context := gui.currentSideContext()
-	listContext, ok := context.(*ListContext)
+	listContext, ok := context.(IListContext)
 	if !ok {
 		return nil
 	}
@@ -399,6 +399,8 @@ func (gui *Gui) onViewFocusLost(oldView *gocui.View, newView *gocui.View) error
 		return nil
 	}
 
+	_ = oldView.SetOriginX(0)
+
 	if oldView == gui.Views.CommitFiles && newView != gui.Views.Main && newView != gui.Views.Secondary && newView != gui.Views.Search {
 		gui.resetWindowForView(gui.Views.CommitFiles)
 		if err := gui.deactivateContext(gui.State.Contexts.CommitFiles); err != nil {
