@@ -724,6 +724,14 @@ func (gui *Gui) GetInitialKeybindings() []*Binding {
 			Handler:     gui.handleFetchRemote,
 			Description: gui.Tr.LcFetchRemote,
 		},
+		{
+			ViewName:    "commits",
+			Contexts:    []string{string(BRANCH_COMMITS_CONTEXT_KEY)},
+			Key:         gui.getKey(config.Commits.OpenLogMenu),
+			Handler:     gui.handleOpenLogMenu,
+			Description: gui.Tr.LcOpenLogMenu,
+			OpensMenu:   true,
+		},
 		{
 			ViewName:    "commits",
 			Contexts:    []string{string(BRANCH_COMMITS_CONTEXT_KEY)},
@@ -1426,6 +1434,20 @@ func (gui *Gui) GetInitialKeybindings() []*Binding {
 			Modifier: gocui.ModNone,
 			Handler:  gui.scrollDownMain,
 		},
+		{
+			ViewName:    "main",
+			Contexts:    []string{string(MAIN_PATCH_BUILDING_CONTEXT_KEY), string(MAIN_STAGING_CONTEXT_KEY), string(MAIN_MERGING_CONTEXT_KEY)},
+			Key:         gui.getKey(config.Universal.ScrollLeft),
+			Handler:     gui.scrollLeftMain,
+			Description: gui.Tr.LcScrollLeft,
+		},
+		{
+			ViewName:    "main",
+			Contexts:    []string{string(MAIN_PATCH_BUILDING_CONTEXT_KEY), string(MAIN_STAGING_CONTEXT_KEY), string(MAIN_MERGING_CONTEXT_KEY)},
+			Key:         gui.getKey(config.Universal.ScrollRight),
+			Handler:     gui.scrollRightMain,
+			Description: gui.Tr.LcScrollRight,
+		},
 		{
 			ViewName:    "main",
 			Contexts:    []string{string(MAIN_STAGING_CONTEXT_KEY)},
