@@ -43,12 +43,16 @@ func TestDetermineLineType(t *testing.T) {
 		},
 		{
 			line:     "=======",
-			expected: MIDDLE,
+			expected: TARGET,
 		},
 		{
 			line:     ">>>>>>> blah",
 			expected: END,
 		},
+		{
+			line:     "||||||| adf33b9",
+			expected: ANCESTOR,
+		},
 	}
 
 	for _, s := range scenarios {
