@@ -4,6 +4,7 @@ import (
 	"strings"
 
 	"github.com/cloudfoundry/jibber_jabber"
+	"github.com/go-errors/errors"
 	"github.com/imdario/mergo"
 	"github.com/sirupsen/logrus"
 )
@@ -14,20 +15,31 @@ type Localizer struct {
 	S   TranslationSet
 }
 
-// NewTranslationSet creates a new Localizer
-func NewTranslationSet(log *logrus.Entry) *TranslationSet {
-	userLang := detectLanguage(jibber_jabber.DetectLanguage)
+func NewTranslationSetFromConfig(log *logrus.Entry, configLanguage string) (*TranslationSet, error) {
+	if configLanguage == "auto" {
+		language := detectLanguage(jibber_jabber.DetectLanguage)
+		return NewTranslationSet(log, language), nil
+	}
 
-	log.Info("language: " + userLang)
+	for key := range GetTranslationSets() {
+		if key == configLanguage {
+			return NewTranslationSet(log, configLanguage), nil
+		}
+	}
+
+	return NewTranslationSet(log, "en"), errors.New("Language not found: " + configLanguage)
+}
+
+func NewTranslationSet(log *logrus.Entry, language string) *TranslationSet {
+	log.Info("language: " + language)
 
 	baseSet := englishTranslationSet()
 
 	for languageCode, translationSet := range GetTranslationSets() {
-		if strings.HasPrefix(userLang, languageCode) {
+		if strings.HasPrefix(language, languageCode) {
 			_ = mergo.Merge(&baseSet, translationSet, mergo.WithOverride)
 		}
 	}
-
 	return &baseSet
 }
 
